package rocks.zipcode.atm;

import javafx.geometry.Pos;
import javafx.scene.layout.GridPane;
import rocks.zipcode.atm.bank.Bank;
import javafx.application.Application;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.stage.Stage;
import javafx.scene.paint.Color;

/**
 * @author ZipCodeWilmington
 */
public class CashMachineApp extends Application {
    Color blue = Color.rgb(0,0,255);

    private CashMachine cashMachine = new CashMachine(new Bank());

    private TextField setAccountIdField = new TextField();
    private TextField setDepositField = new TextField();
    private TextField setWithdrawField = new TextField();

    private Parent createContent() {
        setAccountIdField.setMinSize(250, 40);
        setDepositField.setMinSize(250, 40);
        setWithdrawField.setMinSize(250, 40);

        GridPane gridPane = new GridPane();
        gridPane.setPrefSize(500, 400);
        gridPane.setAlignment(Pos.CENTER);
        gridPane.setStyle("-fx-background-color: Green;");

        TextArea areaInfo = new TextArea();
        areaInfo.setMaxSize(250, 160);


        Button btnDeposit = new Button("Deposit");
        btnDeposit.setMinSize(250, 40);
        btnDeposit.setTextFill(blue);
        btnDeposit.setDisable(true);
        btnDeposit.setOnAction(e -> {
            float amount = Float.parseFloat(setWithdrawField.getText());
            cashMachine.deposit(amount);
            areaInfo.setText(cashMachine.toString());
        });

        Button btnWithdraw = new Button("Withdraw");
        btnWithdraw.setMinSize(250, 40);
        btnWithdraw.setTextFill(blue);
        btnWithdraw.setDisable(true);
        btnWithdraw.setOnAction(e -> {
            float amount = Float.parseFloat(setWithdrawField.getText());
            cashMachine.withdraw(amount);
            areaInfo.setText(cashMachine.toString());
        });

        Button btnExit = new Button("Exit");
        btnExit.setMinSize(250, 160);
        btnExit.setTextFill(blue);
        btnExit.setDisable(true);
        btnExit.setOnAction(e -> {
            btnDeposit.setDisable(true);
            btnWithdraw.setDisable(true);
            btnExit.setDisable(true);
            resetOnExit();
            cashMachine.exit();
            areaInfo.setText(cashMachine.toString());
        });

        Button btnSubmit = new Button("Set Account ID");
        btnSubmit.setMinSize(250, 40);
        btnSubmit.setTextFill(blue);
        btnSubmit.setOnAction(e -> {
            int id = Integer.parseInt(setAccountIdField.getText());
            if (isValidId(id)){
                btnDeposit.setDisable(false);
                btnWithdraw.setDisable(false);
                btnExit.setDisable(false);
            }
            else {
                btnDeposit.setDisable(true);
                btnWithdraw.setDisable(true);
                btnExit.setDisable(true);
            }
            cashMachine.login(id);

            areaInfo.setText(cashMachine.toString());
        });


        GridPane.setConstraints(btnSubmit, 0, 0);
        GridPane.setConstraints(btnDeposit, 0, 1);
        GridPane.setConstraints(btnWithdraw, 0, 2);
        GridPane.setConstraints(btnExit, 0, 3);
        GridPane.setConstraints(setAccountIdField, 1, 0);
        setWithdrawField.setMaxSize(Double.MAX_VALUE, Double.MAX_VALUE);
        GridPane.setConstraints(setWithdrawField, 1, 1, 1, 2);
        GridPane.setConstraints(areaInfo, 1, 3);
        gridPane.getChildren().addAll(btnSubmit, btnDeposit, btnWithdraw, btnExit,
                setAccountIdField, setWithdrawField, areaInfo);
        return gridPane;
    }

    @Override
    public void start(Stage stage) throws Exception {
        stage.setScene(new Scene(createContent()));
        stage.setTitle("Zip Code ATM");
        stage.show();
    }

    public boolean isValidId(int id){
        if (cashMachine.isValidId(id)) {
            return true;
        }
        else {
            return false;
        }
    }

    public void resetOnExit(){
        setAccountIdField.clear();
        setDepositField.clear();
        setWithdrawField.clear();
    }

    public static void main(String[] args) {
        launch(args);
    }
}
